Class: String

Inherits:
Object
  • Object
show all
Defined in:
lib/sb.rb

Overview

Monkeypatch String#dump so that Mote treats “regular” template text (i.e. not user provided interpolated content) as safe.

FIXME: It’d be nice if Mote had some sort of hook method for this so that we didn’t need to monkeypatch anything.

Direct Known Subclasses

SB

Constant Summary collapse

@@dump =
instance_method(:dump)

Instance Method Summary collapse

Instance Method Details

#dumpObject



36
37
38
# File 'lib/sb.rb', line 36

def dump
  "SB(#{@@dump.bind(self).call})"
end